@@ -27,8 +27,9 @@
 #define __WORKSPACE_WINDOW_H__
 
 #include <gtk/gtkwidget.h>
+#include <libmergeant/mg-conf.h>
 
-GtkWidget *workspace_window_new (void);
+GtkWidget *workspace_window_new          (MgConf *conf);
 void       workspace_window_sensitize_ui (GtkWidget *window);
 
 #endif
