@@ -27,23 +27,30 @@
 #define __WORKSPACE_H__
 
 #include <libmergeant/mg-server.h>
-#include <gtk/gtknotebook.h>
+#include <gtk/gtkvbox.h>
+
+#define WORKSPACE_TYPE          (workspace_get_type())
+#define WORKSPACE(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, workspace_get_type(), MgQuery)
+#define WORKSPACE_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, workspace_get_type (), MgQueryClass)
+#define IS_WORKSPACE(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, workspace_get_type ())
 
 typedef struct _WorkspacePrivate WorkspacePrivate;
 
 typedef struct {
-	GtkNotebook parent;
+	GtkVBox           parent;
 	WorkspacePrivate *priv;
 } Workspace;
 
 typedef struct {
-	GtkNotebookClass parent_class;
+	GtkVBoxClass      parent_class;
 } WorkspaceClass;
 
-GType      workspace_get_type (void);
-GtkWidget *workspace_new (MgServer *server);
+GType      workspace_get_type        (void);
+GtkWidget *workspace_new             (MgServer *server);
 
-MgServer  *workspace_get_server (Workspace *wk);
-void       workspace_set_server (Workspace *wk, MgServer *server);
+MgServer  *workspace_get_server      (Workspace *wk);
+void       workspace_set_server      (Workspace *wk, MgServer *server);
+
+void       workspace_queue_conf_save (Workspace *wk);
 
 #endif
