@@ -57,8 +57,6 @@ static gboolean    mg_qf_field_load_from_xml (MgXmlStorage *iface, xmlNodePtr no
 static void              mg_qf_field_field_init      (MgFieldIface *iface);
 static MgEntity         *mg_qf_field_get_entity      (MgField *iface);
 static MgServerDataType *mg_qf_field_get_data_type   (MgField *iface);
-static const gchar      *mg_qf_field_get_name        (MgField *iface);
-static const gchar      *mg_qf_field_get_description (MgField *iface);
 
 /* Renderer interface */
 static void            mg_qf_field_renderer_init   (MgRendererIface *iface);
@@ -196,8 +194,6 @@ mg_qf_field_field_init (MgFieldIface *iface)
 {
 	iface->get_entity = mg_qf_field_get_entity;
 	iface->get_data_type = mg_qf_field_get_data_type;
-	iface->get_name = mg_qf_field_get_name;
-	iface->get_description = mg_qf_field_get_description;
 }
 
 static void
@@ -738,23 +734,6 @@ mg_qf_field_get_data_type (MgField *iface)
 	return NULL;
 }
 
-static const gchar *
-mg_qf_field_get_name (MgField *iface)
-{
-	g_return_val_if_fail (iface && IS_MG_QF_FIELD (iface), NULL);
-
-	return mg_base_get_name (MG_BASE (iface));
-}
-
-static const gchar *
-mg_qf_field_get_description (MgField *iface)
-{
-	g_return_val_if_fail (iface && IS_MG_QF_FIELD (iface), NULL);
-	
-	return mg_base_get_description (MG_BASE (iface));	
-}
-
-
 /* 
  * MgXmlStorage interface implementation
  */
@@ -805,6 +784,10 @@ mg_qf_field_save_to_xml (MgXmlStorage *iface, GError **error)
 	if (field->priv->value_prov_ref)
 		xmlSetProp (node, "value_prov", mg_ref_base_get_ref_name (field->priv->value_prov_ref, NULL, NULL));
 
+	str = mg_qfield_get_alias (MG_QFIELD (field));
+	if (str && *str) 
+		xmlSetProp (node, "alias", str);
+
 	if (field->priv->plugin)
 		xmlSetProp (node, "plugin", field->priv->plugin);
 
@@ -903,6 +886,12 @@ mg_qf_field_load_from_xml (MgXmlStorage *iface, xmlNodePtr node, GError **error)
 		g_free (prop);
 	}
 
+	prop = xmlGetProp (node, "alias");
+	if (prop) {
+		mg_qfield_set_alias (MG_QFIELD (field), prop);
+		g_free (prop);
+	}
+
 	prop = xmlGetProp (node, "plugin");
 	if (prop) 
 		field->priv->plugin = prop;
